# upload

Ce composant permet aux utilisateurs de sélectionner et envoyer un ou plusieurs fichiers.

## Utilisation
Afin d’utiliser le composant `upload`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/upload/upload.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/composants/ajout-de-fichier) sur le module Ajout de fichier